<?php
/* 
Plugin Name: FAQ Revolution
Plugin URI: https://lcweb.it/faq-revolution-wordpress-plugin
Description: A complete system to answer site visitor questions step-by-step and create knowledge-base
Author: Luca Montanari (LCweb)
Version: 1.1.2
Author URI: https://lcweb.it
*/  



/////////////////////////////////////////////
/////// MAIN DEFINES ////////////////////////
/////////////////////////////////////////////

// plugin path
$wp_plugin_dir = substr(plugin_dir_path(__FILE__), 0, -1);
define('FR_DIR', $wp_plugin_dir);

// plugin url
$wp_plugin_url = substr(plugin_dir_url(__FILE__), 0, -1);
define('FR_URL', $wp_plugin_url);


// plugin version
define('FR_VER', '1.1.2');

// multilang key
define('FR_ML', 'fr_ml');




/////////////////////////////////////////////
/////// FORCING DEBUG ///////////////////////
/////////////////////////////////////////////

if(isset($_REQUEST['fr_php_debug'])) {
	ini_set('display_errors', 1);
	ini_set('display_startup_errors', 1);
	error_reporting(E_ALL);	
}




/////////////////////////////////////////////
/////// MULTILANGUAGE SUPPORT ///////////////
/////////////////////////////////////////////

function fr_multilanguage() {
	$param_array = explode(DIRECTORY_SEPARATOR, FR_DIR);
 	$folder_name = end($param_array);
	load_plugin_textdomain('fr_ml', false, $folder_name . '/languages'); 
}
add_action('init', 'fr_multilanguage', 1);





/////////////////////////////////////////////
/////// MAIN SCRIPT & CSS INCLUDES //////////
/////////////////////////////////////////////


// global script enqueuing
function fr_global_scripts() {
	wp_enqueue_script('jquery');
	$is_admin = is_admin();

    // magnificPopup (used everywhere)
    wp_enqueue_style('lcwp-magpopup', FR_URL .'/js/magnific-popup/magnific-popup-style.css');
    wp_enqueue_script('lcwp-magpopup', FR_URL .'/js/magnific-popup/magnific-popup.min.js', 70, '1.1.0', !(bool)get_option('fr_js_head'));
    
    
	// admin
	if($is_admin) {  
		global $current_screen;
        if(!$current_screen) {
            return;     
        }
        
        wp_enqueue_style('fr_admin', FR_URL . '/css/admin.css', 999, FR_VER);
		
        // sortable
		wp_enqueue_script('jquery-ui-sortable');
        
        // lightbox and thickbox
		wp_enqueue_script('media-upload');
        
		// LC tools
		wp_enqueue_style('lcwp-lc-select',      FR_URL .'/js/lc-select/themes/lcwp_prefixed.css');
        wp_enqueue_script('lc-select',          FR_URL .'/js/lc-select/lc_select.min.js', 100, '1.1.3', true);
        
		wp_enqueue_script('lc-wp-popup-message',FR_URL .'/js/lc-wp-popup-message/lc_wp_popup_message.min.js', 200, '1.0', true);
        wp_enqueue_script('lc-switch-v2',       FR_URL .'/js/lc-switch/lc_switch.min.js', 200, '2.0.3', true);

        
        // settings page scripts
        if($current_screen->base == 'faq-revolution_page_fr_settings') {
            $baseurl = FR_URL .'/js';
            wp_enqueue_style('fr_settings', FR_URL .'/settings/settings_style.css', 999, FR_VER);	
            
            wp_enqueue_script('lc-range-n-num',     $baseurl .'/lc-range-n-num/lc_range_n_num.min.js', 200, '1.0', true);
            wp_enqueue_script('lc-color-picker',    $baseurl .'/lc-color-picker/lc_color_picker.min.js', 200, '1.1.1', true);
            
            wp_enqueue_style('codemirror',          $baseurl .'/codemirror/codemirror.css');
            wp_enqueue_script('codemirror',         $baseurl .'/codemirror/codemirror.min.js', 200, '1.0', true);
            wp_enqueue_script('codemirror-lang-css',$baseurl .'/codemirror/languages/css.min.js', 201, '1.0', true);
        }
	}
	
	
	// frontend
	if(!$is_admin || isset($GLOBALS['lc_guten_scripts'])) {
        add_action('wp_head', 'fr_head_js', 10);
		add_action('lc_scripts_in_guten_head', 'fr_head_js');
		
		wp_enqueue_style('dashicons');
		wp_enqueue_style('fr-justGall', FR_URL .'/js/justified_gallery/css/justifiedGallery.min.css');
        wp_enqueue_style('fr-simplelb', FR_URL .'/js/simplelightbox/simplelightbox.min.css');
        
        wp_enqueue_style('fr-frontend', FR_URL .'/css/frontend.min.css');
        if(class_exists('DiviExtension')) {
            wp_enqueue_style('fr-frontend-for-divi', FR_URL .'/css/frontend.min_for_divi.css');        
        }
        
        
		// frontent JS on header or footer
		wp_enqueue_script('fr-justGall', FR_URL .'/js/justified_gallery/js/jquery.justifiedGallery.min.js', 800, '3.7.0', !(bool)get_option('fr_js_head'));	
        wp_enqueue_script('fr-simplelb', FR_URL .'/js/simplelightbox/simple-lightbox.min.js', 800, '1.13.0', !(bool)get_option('fr_js_head'));	
        wp_enqueue_script('fr-frontend', FR_URL .'/js/faq_revo.min.js', 801, FR_VER, !(bool)get_option('fr_js_head'));

        
		// frontend css
		if(!get_option('fr_inline_css')) {
			wp_enqueue_style('fr-custom', FR_URL .'/css/custom.css', 100, FR_VER .'-'. get_option('fr_dynamic_scripts_id'));	
		}
		else {add_action('wp_head', 'fr_inline_css', 989);}	
	}
}
add_action('wp_enqueue_scripts', 'fr_global_scripts', 900);
add_action('admin_enqueue_scripts', 'fr_global_scripts');
add_action('lc_guten_scripts', 'fr_global_scripts');



// use frontend CSS inline
function fr_inline_css() {
	if(isset($GLOBALS['fr_printed_inline_css'])) { // avoid double enqueuing with Gutenberg
		return false;	
	}
	$GLOBALS['fr_printed_inline_css'] = true;
	
	echo 
    '<style type="text/css">'.
	   fr_custom_css_less_parser() .
	'</style>';
}



// frontend JS global variables
function fr_head_js() {
	$is_search_pag = 'false';
	if(is_page()) {
		global $post;
		$checked_id = fr_wpml_translated_pag_id($post->ID);
		
		foreach((array)get_option('fr_faq_search_pag') as $fsp) {
			
			if($checked_id == fr_wpml_translated_pag_id($fsp)) {
				$is_search_pag = 'true';
				break;	
			}
		}
	}
	
	?>
    <script type="text/javascript">
	fr_siteurl 			= '<?php echo site_url() ?>'; 
	fr_faq_pag_baseurl 	= '<?php echo ($is_search_pag == 'true') ? untrailingslashit( get_permalink($post->ID)) : ''; ?>'; 
    fr_sel_an_opt_txt		= "<?php echo addslashes( __('select an option', FR_ML)) ?>";
	fr_any_sub_subj_txt 	= "<?php echo addslashes( get_option('fr_any_sub_subj_txt')) ?>";
	fr_gall_img_h			= <?php echo (int)get_option('fr_faq_img_h', 100) ?>;
	fr_kb_legend 			= "<?php echo addslashes( get_option('fr_kb_legend', 'Related articles:')) ?>";
	fr_after_vote_txt		= "<?php echo addslashes( __('Thanks for your vote!', FR_ML)) ?>";
	fr_no_sub_subjs 		= <?php echo (get_option('fr_no_sub_subjs')) ? 'true' : 'false' ?>;
	fr_is_faq_search_pag 	= <?php echo $is_search_pag ?>; 
	fr_no_deepling 		= <?php echo (get_option('fr_subj_deepl_type') == 'none') ? 'true' : 'false' ?>; 
	fr_only_faq_pag 		= <?php echo (get_option('fr_only_faq_pag')) ? 'true' : 'false' ?>; 
	
    fr_req_src			= [];
	fr_subj 			= [];
	fr_sub_subj 		= [];
	fr_sub_subjs_list 	= [];
	fr_faq 				= [];
    fr_excl_subj        = [];
    </script>
    <?php
}








/////////////////////////////////////////////
/////// MAIN INCLUDES ///////////////////////
/////////////////////////////////////////////

include_once(FR_DIR . '/functions.php');

// admin menu and cpt and taxonomy
include_once(FR_DIR . '/admin_menu.php');

// admin ajax
include_once(FR_DIR . '/admin_ajax.php');

// FAQ metaboxes (search helper and builder)
include_once(FR_DIR . '/faq_builder.php');

// External links port type hacks
include_once(FR_DIR . '/ext_links_pt_hacks.php');

// Subjects taxonomy custom fields
include_once(FR_DIR . '/subjs_tax_meta.php');

// TinyMCE Integration
include_once(FR_DIR . '/tinymce_integration.php');



// front faq code class (applies also contents to direct FAQ pages)
include_once(FR_DIR . '/classes/front_faq_code.php');

// special rewrite rules for FAQ search page
include_once(FR_DIR . '/faq_pag_rewrite_rule.php');

// public api
include_once(FR_DIR . '/public_api.php');

// shortcode
include_once(FR_DIR . '/shortcode.php');

// KB tags displaying
include_once(FR_DIR . '/kb_tags_on_frontend.php');

// frontend ajax
include_once(FR_DIR . '/front_ajax.php');

// woocommerce product tab
include_once(FR_DIR . '/classes/woocomm_tab.php');




// gutenberg integration - not for WP 5.8 widgets.. for now
if($_SERVER["REQUEST_URI"] != '/wp-admin/widgets.php') {
    include_once(FR_DIR . '/builders_integration/gutenberg.php');
}

// visual composer integration
include_once(FR_DIR . '/builders_integration/visual_composer.php');

// elementor integration
include_once(FR_DIR . '/builders_integration/elementor.php');

// divi integration
include_once(FR_DIR . '/builders_integration/divi.php');





////////////
// AVOID issues with bad servers in settings redirect
function fr_settings_redirect_trick() {
	ob_start();
}
add_action('admin_init', 'fr_settings_redirect_trick', 1);
////////////








////////////
// DOCUMENTATION'S LINK	
function fr_doc_link($links, $file) {
	if($file == plugin_basename(__FILE__)) {	
		$links['lc_doc_link'] = '<a href="https://doc.lcweb.it/faq_revo" target="_blank">'. __('Documentation', 'fr_ml') .'</a>';
	}
	
	return $links;
}
add_filter('plugin_row_meta', 'fr_doc_link', 50, 2);
////////////




////////////
// AUTO UPDATE DELIVER
function fr_auto_updates() {
	if(!get_option('fr_no_auto_upd')) {
        include_once(FR_DIR . '/classes/lc_wp_auto_updater/lc_plugin_auto_updater.php');
        
		$upd = new lc_wp_autoupdate(__FILE__, 'http://updates.lcweb.it', 'lc_updates', 'fr_on_activation');
        $upd->ml_key = FR_ML;
	}
}
add_action('admin_init', 'fr_auto_updates', 1);
////////////








/////////////////////////////////////////////
////// ACTIONS ON PLUGIN ACTIVATION /////////
/////////////////////////////////////////////

function fr_on_activation() {
	// create custom CSS
	if(!fr_create_dynamic_css()) {
		if(!get_option('fr_inline_css')) {update_option('fr_inline_css', 1);}
	}
	else {delete_option('fr_inline_css');}
	
}
register_activation_hook(__FILE__, 'fr_on_activation');

