<?php
// ADDS STATUS, FEATURED IMAGE and ORDER FIELDS TO FAQ SUBJECTS TAXONOMY


// add the order field
add_action('fr_faq_subjs_add_form_fields'	, 'fr_subjs_cust_fields', 10, 2 );
add_action('fr_faq_subjs_edit_form_fields' 	, 'fr_subjs_cust_fields', 10, 2);


function fr_subjs_cust_fields($tax_data) {
    
	//check for existing taxonomy meta for term ID
    $image 	= (is_object($tax_data)) ? (string)fr_get_term_meta($tax_data->term_id, 'fr_subj_img') : '';
    $status	= (is_object($tax_data)) ? (int)fr_get_term_meta($tax_data->term_id, 'fr_disable_subj') : '';
    $order = (is_object($tax_data)) ? (int)fr_get_term_meta($tax_data->term_id, 'fr_subj_order') : 0;
	
	
	// creator layout
	if(!is_object($tax_data)) :
?>
		<div class="form-field">
            <label><?php _e('Image', FR_ML) ?></label>
           	<?php fr_subj_img_field($image); ?>
            <p><?php _e('Set an image representing the subject (optional)', FR_ML) ?></p>
        </div>

        <div class="form-field">
            <label><?php esc_html_e('Order', FR_ML) ?></label>
           	<input type="number" name="fr_subj_order" value="<?php echo $order ?>" min="0" max="1000" step="1" autocomplete="off" /> 
            <p><?php esc_html_e('Custom subject sorting order', FR_ML) ?></p>
        </div>
        
		<div class="form-field">
            <label>
            	<input type="checkbox" name="fr_disable_subj" value="1" autocomplete="off" />
				<?php _e('Disable subject?', FR_ML) ?>
            </label>
            <p><?php _e('Check to hide this subject on frontend choices', FR_ML) ?></p>
        </div>
	<?php
	
	
	else:
	
	
	?>
    <tr class="form-field">
        <th scope="row" valign="top"><label><?php _e('Image', FR_ML) ?></label></th>
        <td>
            <div class="mg_type_opt_icon_trigger">
                <?php fr_subj_img_field($image); ?>
            </div>
            <p class="description"><?php _e('Set an image representing the subject (optional)', FR_ML) ?></p>
        </td>
    </tr>
    <tr class="form-field">
        <th scope="row" valign="top"><label><?php esc_html_e('Order', 'mg_ml') ?></label></th>
        <td>
            <input type="number" name="fr_subj_order" value="<?php echo $order ?>" min="0" max="1000" step="1" autocomplete="off" /> 
            <p class="description"><?php esc_html_e('Custom subject sorting order', FR_ML) ?></p>
        </td>
    </tr>
    <tr class="form-field">
        <th scope="row" valign="top"><label><?php _e('Disable subject?', FR_ML) ?></label></th>
        <td>
            <input type="checkbox" name="fr_disable_subj" value="1" <?php echo (!empty($status)) ? 'checked="checked"' : '' ?> />
            <p class="description"><?php _e('Check to hide this subject on frontend choices', FR_ML) ?></p>
        </td>
    </tr>
<?php
	endif;
}




// save metas
function fr_subj_save_cust_fields($term_id) {
	
	$keys = array('fr_subj_img', 'fr_disable_subj', 'fr_subj_order');
	foreach($keys as $key) {
		
		$val = (isset($_POST[$key]) && !empty($_POST[$key])) ? (int)$_POST[$key] : '';
		fr_set_term_meta($term_id, $key, $val);
	}
}
add_action('created_fr_faq_subjs'	, 'fr_subj_save_cust_fields', 10, 2);
add_action('edited_fr_faq_subjs'	, 'fr_subj_save_cust_fields', 10, 2);




// clean metas on deletion
function fr_subj_del_term_opts($term, $tt_id, $taxonomy, $deleted_term) {
	
    $keys = array('fr_subj_img', 'fr_disable_subj', 'fr_subj_order');
	foreach($keys as $key) {
        fr_del_term_meta($term, $key);        
    }
}
add_action('delete_term', 'fr_subj_del_term_opts', 10, 4);




/////////////////////////////////////////////////////////////////////////




// display custom fields in tax table
add_filter('manage_edit-fr_faq_subjs_columns'	, 'fr_faq_subjs_column_headers', 10, 1);
add_filter('manage_fr_faq_subjs_custom_column'	, 'fr_faq_subjs_column_row', 10, 3);


// add columns
function fr_faq_subjs_column_headers($columns) {
    $prepend_cols = array();
	$append_cols = array();
	
	$prepend_cols['fr_subj_status'] = '<span class="dashicons dashicons-marker" title="'. esc_attr(__('Subject status flag', FR_ML)) .'" style="color: #0073aa; cursor: help;"></span>';
    $append_cols['fr_subj_img']		= __("Image", FR_ML);
    $append_cols['fr_subj_order']	= __("Order", FR_ML);
	
	if(count($prepend_cols) > 0) {
		$columns = array_slice($columns, 0, 1, true) + $prepend_cols + array_slice($columns, 1, count($columns)-1, true);
	}
    return array_merge($columns, $append_cols);
}


// fill new rows
function fr_faq_subjs_column_row($row_content, $column_name, $term_id) {
	if($column_name == 'fr_subj_status') {
		$val = fr_get_term_meta($term_id, 'fr_disable_subj'); 

		return (empty($val)) ? 
			'<span class="dashicons dashicons-marker" title="'. esc_attr(__('Subject active', FR_ML)) .'" style="color: #4f9524; cursor: help;"></span>' :
			'<span class="dashicons dashicons-marker" title="'. esc_attr(__('Subject disabled', FR_ML)) .'" style="color: #cc0000; cursor: help;"></span>';	
	}
	
	
	elseif($column_name == 'fr_subj_img') {
		$img_id = fr_get_term_meta($term_id, 'fr_subj_img'); 
		
		if(empty($img_id)) {
			return '';
		} else {
			$img_data = wp_get_attachment_image_src($img_id);
			return '<img src="'. $img_data[0] .'" alt="'. esc_attr(get_the_title($img_id)) .'" style="width: 80px; height: 80px;" />';	
		}
	}
    
    elseif($column_name == 'fr_subj_order') {
		return (int)fr_get_term_meta($term_id, 'fr_subj_order'); 
	}
	
	else {
		return '&nbsp;';
	}
}





/////////////////////////////////////////////////////////////////////////




/* RENAME SLUG TO "REF ID" ?? // TODO
function foo() {
	global $current_screen;
    
	// remove parent field
	if($current_screen->id == 'edit-fr_faq_subjs') {
		?>
		<script type="text/javascript">
		jQuery(document).ready( function($) {
			jQuery('#parent').parents('.form-field').remove();
		});
		</script>
		<?php
    }
}
add_action('admin_footer-edit-tags.php', 'mg_edit_item_cat_js');
add_action('admin_footer-term.php', 'mg_edit_item_cat_js');
*/
